package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````(`/@`!````$"1```````!``````````-C$````
M`````````$``.``(`$``'0`<``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````<`````````!P``````````0`````````!````
M!0````````````````!``````````$```````!QC````````'&,`````````
M`"````````$````&````(&,````````@8V```````"!C8```````9&``````
M```@<0``````````(````````@````8````X8P```````#AC8```````.&-@
M```````P`@```````#`"````````"``````````$````!````!P"````````
M'`)````````<`D```````$0`````````1``````````$`````````%#E=&0$
M`````%T`````````74````````!=0```````]`````````#T``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"``````````O;&EB-C0O;&0M;&EN=7@M>#@V+38T+G-O+C(`
M!````!`````!````1TY5```````"````!@```!H````$````%`````,```!'
M3E4`;>%_!TYJUY>.-_DQ/_?,%B@N";QA````:0````````````````````4`
M`````````````#8`````````'@```"H````?`````````#\````*````5P``
M```````5````20```$H````F````6P```&8````'````0```````````````
M`P```%T````]``````````````!.````50```%$````Y`````````&@```!-
M````/@```#``````````-P````````!2`````````$@````X````````````
M``!A````.P```!0````<``````````````!4````)P```#(````K````````
M```````)`````````"D``````````````$0``````````0```"4````+````
M0P```%D```!"``````````````!>````4````"P```!:````00```#0````Q
M`````````%\```````````````````!@````3P`````````M````5@```#,`
M```,````6`````(`````````````````````````````````````````````
M```````$````````````````````8@``````````````````````````````
M`````````````````````!8`````````9P``````````````"````!<`````
M````````````````````90`````````3````&@```$4````2````8P```!D`
M``!<````*````$8`````````(P`````````8````+P```"``````````````
M`````````````````$P`````````````````````````/```````````````
M.@```$L```!D````-0`````````````````````````````````````````0
M````&P````T```````````````8````=````(0```"(`````````)```````
M````````+@```!$````.``````````````!3````````````````````````
M```````/``````````````!'```````````````1````10````0````(````
M(!P0``5`!(8J`D``D(8!J$(H`"!)(`0+N*(X3;H$!@I%````1@```$H```!/
M````4````%<```!9````6P```%X```!@`````````&(```!E````9@```&<`
M`````````````'OP2FMNQ=\?ZM/O#L[>1RUK?YI\+L6;MB#_Y`Y\08[%N(WQ
M#M5DU'S9<5@<XD?&`:Q+X\#RV],=NN.2?,+E/RSZH6Q@LP&+;VH)0]:'^9R!
M9J_,9L6YG$!"1=7LQ(D%D#GRBQP,%.*>R=6R<=K-XYXS8MOM##J7"U:DFY:G
MW:-K?ZF<F^&G`@H*BA!7H^#[20``````````````````````````````````
M```]`0``$@`````````````````````````V`@``$@``````````````````
M``````#%`@``$@````````````````````````"L`@``$@``````````````
M``````````"2`@``$@`````````````````````````1````(```````````
M``````````````#,`@``$@````````````````````````!*`P``$@``````
M``````````````````#3````$@````````````````````````#A`@``$@``
M```````````````````````D`P``$@`````````````````````````<`P``
M$@````````````````````````"O````$@````````````````````````#^
M`P``$@`````````````````````````X`0``$@``````````````````````
M```$`P``$@````````````````````````#O`@``$@``````````````````
M``````"T`@``$@````````````````````````!#`P``$@``````````````
M``````````!:`P``$@````````````````````````"A`0``$@``````````
M``````````````!A`0``$@````````````````````````#V`@``$@``````
M``````````````````#A````$@````````````````````````#K`0``$@``
M``````````````````````!C`@``$@````````````````````````"C`@``
M$@````````````````````````"(`0``$@````````````````````````!S
M`@``$@````````````````````````":`@``$@``````````````````````
M``#8`0``$@````````````````````````#:`@``$@``````````````````
M```````Q`@``$@````````````````````````")`P``$@``````````````
M```````````*`P``$@````````````````````````""`P``$@``````````
M``````````````!O`0``$@````````````````````````!A`P``$@``````
M```````````````````M````(`````````````````````````!X````$@``
M```````````````````````/`0``$@````````````````````````!/`@``
M$@````````````````````````#D`0``$@````````````````````````"^
M````$@````````````````````````"6`0``$@``````````````````````
M``!J````$@````````````````````````!"`0``$@``````````````````
M``````#-`0``$@`````````````````````````<`0``$@``````````````
M``````````#2`@``$@`````````````````````````J`@``$@``````````
M``````````````!S`P``$@````````````````````````!I`P``$@``````
M``````````````````"O`0``$@````````````````````````![`P``$@``
M``````````````````````#H`@``$@`````````````````````````\````
M(`````````````````````````#S````$@````````````````````````!3
M`P``$@````````````````````````!_`0``$@``````````````````````
M```1`P``$@````````````````````````"*`@``$@``````````````````
M``````"%`@``$@````````````````````````!'`@``$@``````````````
M``````````"'````$@````````````````````````!0````(```````````
M``````````````#]`@``$@`````````````````````````N`P``$@``````
M``````````````````"]`0``$@```&`>0``````````````````'!```$@`.
M`"!80```````=`````````#5`P``$@`/`)Q90``````````````````L!```
M$@`.`*!)0```````G0H```````"6`P``$@`.```B0```````#@(```````#;
M`P``$@`.`*!#0```````!0````````"0!```$@`.`+!#0```````J0$`````
M``"]!```$@`.`*!80```````.@````````"*!```$@`,`*@=0```````````
M``````#9!```$@`.`$!40```````WP,```````"Z`P``$`#Q_X3#8```````
M```````````3!```$@`.`&!%0```````*`````````!&!```$0`0`*A90```
M````!`````````#V`0``$0`:`,##8```````$P````````#&`P``$`#Q_T#4
M8`````````````````"(!```$@`.`&!"0```````*@````````"=!```$@`.
M`)!(0```````"0$```````"O!```$@`.`!!(0```````3``````````Y!```
M$``9`*!G8`````````````````">````$@```#`A0``````````````````@
M!```$@`.`)!%0```````KP````````";`P``$0`:`+##8```````"```````
M``"S`P``$`#Q_X3#8`````````````````"<`P``(0`:`+##8```````"```
M```````\`P``$0`:`-C#8```````"`````````#+`P``$@`.``!90```````
M`@````````!.`0``$@```)`@0`````````````````!K!```$@`.`!!90```
M````B0`````````_!```$@`.`!`D0``````````````````[!```(``9`*!G
M8``````````````````M`0``$0`:`*##8```````!`````````"=`P``(0`:
M`+##8```````"`````````#L`P``$@`.`&!(0```````)`````````!5!```
M$@`.`.!"0```````L0`````````"`0``$0`:`*C#8````````0````````![
M!```$@`.`$!&0```````RP$`````````;&EB<&5R;"YS;RXU+C$T`%])5$U?
M9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G
M:7-T97)#;&%S<V5S`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S
M>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7W-A=F5?9&5S=')U8W1O<E]X
M`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]C<F]A:U]N
M;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L
M7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=35G!V`%!E<FQ?;F5W
M6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R
M;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V
M`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N97=84P!P97)L7V1E<W1R
M=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`
M4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``
M;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A9"YS;RXP`&]P96XV-`!R
M96%D`%]?97)R;F]?;&]C871I;VX`;'-E96LV-`!P=&AR96%D7V=E='-P96-I
M9FEC`&-L;W-E`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-P
M<FEN=&8`<W1R;F-M<`!?7W-T<F1U<`!C;&]S961I<@!S=')N8W!Y`%]?<W1A
M8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`;65M8VAR`&=E='!I
M9`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S=')S='(`<FUD:7(`;65M8W!Y`%]?
M;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`7U]C='EP95]B7VQO8P!S=&1E
M<G(`9V5T=6ED`')E861L:6YK`&5X96-V<`!S=')C:'(`9G!R:6YT9@!R96%D
M9&ER-C0`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN
M`%]?96YV:7)O;@!L:6)C<GEP="YS;RXQ`%]E9&%T80!?7V)S<U]S=&%R=`!?
M96YD`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R
M;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P
M87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T`%])3U]S=&1I
M;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`
M<&%R7VEN:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L
M:6)P871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!4E]#3$5!4E-4
M04-+`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C(N-0!'3$E"0U\R
M+C,`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXT``````(``P`"``(``@````(``@``
M``(``@`"`````@````(``@`$``(``@```````@```````P`"````!0`"````
M`@`#``(``@`"`````@`````````#``(``````````````````@`#``(``@``
M``(``@```````@````(``@`"``,```````(`!@````$``0`!``$``0`!``$`
M`0`!``$``0`!`````0`!``$``0`!`````0`"``$``@`"``$````!``$``0``
M``(``0`!`````0````$``0`:`@``$````"````!U&FD)```#`.\$````````
M`0`$`&D"```0`````````!-I:0T```8`^P0``!````!R&6D)```%``4%```0
M````%&EI#0``!``1!0``$````'4::0D```(`[P0```````!H96````````8`
M```G``````````````"@PV````````4```!C``````````````"HPV``````
M``4```!G``````````````"PPV````````4```!:``````````````#`PV``
M``````4```!2``````````````#8PV````````4```!=``````````````"(
M96````````<````!``````````````"096````````<````"````````````
M``"896````````<````#``````````````"@96````````<````$````````
M``````"H96````````<````%``````````````"P96````````<````'````
M``````````"X96````````<````(``````````````#`96````````<````)
M``````````````#(96````````<````*``````````````#096````````<`
M``!%``````````````#896````````<````+``````````````#@96``````
M``<````,``````````````#H96````````<````-``````````````#P96``
M``````<````.``````````````#X96````````<````/````````````````
M9F````````<````0```````````````(9F````````<````1````````````
M```09F````````<````2```````````````89F````````<````3````````
M```````@9F````````<````4```````````````H9F````````<````5````
M```````````P9F````````<````6```````````````X9F````````<````7
M``````````````!`9F````````<````8``````````````!(9F````````<`
M```9``````````````!09F````````<````:``````````````!89F``````
M``<````;``````````````!@9F````````<````<``````````````!H9F``
M``````<````=``````````````!P9F````````<````>``````````````!X
M9F````````<````?``````````````"`9F````````<````@````````````
M``"(9F````````<````A``````````````"09F````````<````B````````
M``````"89F````````<````C``````````````"@9F````````<````D````
M``````````"H9F````````<````E``````````````"P9F````````<````F
M``````````````"X9F````````<````H``````````````#`9F````````<`
M```I``````````````#(9F````````<````J``````````````#09F``````
M``<````K``````````````#89F````````<````L``````````````#@9F``
M``````<````M``````````````#H9F````````<```!?``````````````#P
M9F````````<````N``````````````#X9F````````<````O````````````
M````9V````````<````P```````````````(9V````````<````Q````````
M```````09V````````<````R```````````````89V````````<````S````
M```````````@9V````````<````T```````````````H9V````````<````U
M```````````````P9V````````<````V```````````````X9V````````<`
M``!8``````````````!`9V````````<````W``````````````!(9V``````
M``<````X``````````````!09V````````<````Z``````````````!89V``
M``````<````[``````````````!@9V````````<````\``````````````!H
M9V````````<````]``````````````!P9V````````<````^````````````
M``!X9V````````<````_``````````````"`9V````````<```!`````````
M``````"(9V````````<```!!``````````````"09V````````<```!#````
M``````````"89V````````<```!$``````````````!(@^P(Z(L&``!(@\0(
MPP````````````#_-;)'(`#_);1'(``/'T``_R6R1R``:`````#IX/____\E
MJD<@`&@!````Z=#_____):)'(`!H`@```.G`_____R6:1R``:`,```#IL/__
M__\EDD<@`&@$````Z:#_____)8I'(`!H!0```.F0_____R6"1R``:`8```#I
M@/____\E>D<@`&@'````Z7#_____)7)'(`!H"````.E@_____R5J1R``:`D`
M``#I4/____\E8D<@`&@*````Z4#_____)5I'(`!H"P```.DP_____R521R``
M:`P```#I(/____\E2D<@`&@-````Z1#_____)4)'(`!H#@```.D`_____R4Z
M1R``:`\```#I\/[___\E,D<@`&@0````Z>#^____)2I'(`!H$0```.G0_O__
M_R4B1R``:!(```#IP/[___\E&D<@`&@3````Z;#^____)1)'(`!H%````.F@
M_O___R4*1R``:!4```#ID/[___\E`D<@`&@6````Z8#^____)?I&(`!H%P``
M`.EP_O___R7R1B``:!@```#I8/[___\EZD8@`&@9````Z5#^____)>)&(`!H
M&@```.E`_O___R7:1B``:!L```#I,/[___\ETD8@`&@<````Z2#^____)<I&
M(`!H'0```.D0_O___R7"1B``:!X```#I`/[___\END8@`&@?````Z?#]____
M);)&(`!H(````.G@_?___R6J1B``:"$```#IT/W___\EHD8@`&@B````Z<#]
M____)9I&(`!H(P```.FP_?___R621B``:"0```#IH/W___\EBD8@`&@E````
MZ9#]____)8)&(`!H)@```.F`_?___R5Z1B``:"<```#I</W___\E<D8@`&@H
M````Z6#]____)6I&(`!H*0```.E0_?___R5B1B``:"H```#I0/W___\E6D8@
M`&@K````Z3#]____)5)&(`!H+````.D@_?___R5*1B``:"T```#I$/W___\E
M0D8@`&@N````Z0#]____)3I&(`!H+P```.GP_/___R4R1B``:#````#IX/S_
M__\E*D8@`&@Q````Z=#\____)2)&(`!H,@```.G`_/___R4:1B``:#,```#I
ML/S___\E$D8@`&@T````Z:#\____)0I&(`!H-0```.F0_/___R4"1B``:#8`
M``#I@/S___\E^D4@`&@W````Z7#\____)?)%(`!H.````.E@_/___R7J12``
M:#D```#I4/S___\EXD4@`&@Z````Z4#\____)=I%(`!H.P```.DP_/___R72
M12``:#P```#I(/S___\ERD4@`&@]````Z1#\____)<)%(`!H/@```.D`_/__
M_R6Z12``:#\```#I\/O___\ELD4@`&A`````Z>#[____):I%(`!H00```.G0
M^____R6B12``:$(```#IP/O__U-(@^P@B7PD'$B)="002(U\)!Q(B50D"$B-
M="002(U4)`CH"?[__[J0($``OS`A0`!(B=;HIS8``(`]:*$@``!U+^@)_?__
M2(7`2(D%Y[$@``^$G`$``$B)Q^@Q_/__BST[H2``Z.;]___&@,P$````BSTI
MH2``Z-3]__^`B#L%```"BST7H2``Z,+]__^+?"0<@(@[!0```8/'!4AC_TB%
M_P^($P$``/)(#RK'\@]8!3LZ``!F#RX%.SH```^'.@$``$C!YP/HY/S__TB+
M3"002(D%2+$@`,<%1K$@``0```!(BQ%(QT`(D5M``$C'0!#@9V``2,=`&)1;
M0`!(B1"+5"0<@_H!?BJ-<OY,C03U"````#'V9BX/'X0``````$B+?#$(2(E\
M,"!(@\8(3#G&=>V-2@1(BSW[L"``@\(#13'`OI!"0`!(8\E(QT3(^`````!(
MB<'H9/W__X7`B<-T-DB+/<^P(`#HHOO__S'`OU5:0`#H!A@``$B%P'0I2(L]
MLK`@`.@E^___Z!#]__](@\0@B=A;PTB+/9FP(`#HW/W__XG#Z[I(BSV!L"``
M2(7_="3H9S0``.O$2(GX2(GZ2-'H@^(!2`G0\D@/*L#R#UC`Z=7^__^_"EI`
M`.B>%P``2(7`2(G'2(D%0;`@`'2.Z\&_`0```.BS_?__OL##8`"_!5I``#'`
MZ&+\__^0D#'M28G17DB)XDB#Y/!05$G'P`!90`!(Q\$064``2,?'`")``.BG
M^___])"02(/L"$B+!2%!(`!(A<!T`O_02(/$",.0D)"0D)"0D)"0D)"0N(_#
M8`!52"V(PV``2(/X#DB)Y7<"7<.X`````$B%P'3T7;^(PV``_^`/'X``````
MN(C#8`!52"V(PV``2,'X`TB)Y4B)PDC!ZC](`=!(B<9(T?YU`EW#N@````!(
MA=)T]%V_B,-@`/_B#Q^``````(`]"9\@``!U$55(B>7H?O___UW&!?:>(``!
M\\,/'T``2(,].#X@``!T&[@`````2(7`=!%5OS!C8`!(B>7_T%WI>____^EV
M____D)"0D)"0059,C4<X,<E!54%455-(@>P(`@``#Q\`28L4"$B)T$B)UDC!
MX`A(P>88)0``_P")]D@)\$B)UDC![@B!Y@#_``!("?!(B=9(P>X8@>;_````
M2`GP2(G62,'N($B)1$R(2(GP2,'F&$C!X`B)]B4``/\`2`GP2(G62,'J.$C!
M[BB!Y@#_``!("?!("=!(B41,D$B#P0A(@_E`#X5Y____2(U4)(A(C;0D\`$`
M`$B#PFA(BT+82#,"2#-"J$@S0IA(B<%(`<!(P>D?2`G!B<E(B4H82(/""$@Y
M\G752(L73(M?($R+1PA,BT\03(M7&$R)V4B)T$@#3"2(2(G62,'H&TR)Q4C!
MY@5(P>T"3(G32`GP2`-<))!-B<R)P$P#9"282(VT`9EY@EI,B<!,B<E(]]!,
M(<%,(=!("<A(B=$!QDR)P$CWT4C!X!Y,(<E)B?5("<6)[4B)Z$@AT$@)R$B-
MC`.9>8):2(GP2(GS2,'C!4C!Z!M("=A(B=,!P4B)T$C!ZP)(P>`>2`G#2(GP
MB=M(]]!)(=U((>A,">A)B<U-C:0$F7F"6DB)R$G!Y05(P>@;3`GH28G-1`'@
M28GT2,'F'DG![`))"?1(`VPDH$B)SD6)Y$CWUDTAY4@AWD@#7"2H3`GN28G%
M2(VL-9EY@EI(B<9)P>4%2,'N&TP)[DF)Q0'N2(G-2,'A'DC![0)("<U(B<&)
M[4CWT4PAX4DA[4P#9"2P3`GI28GU2(V<"YEY@EI(B?%)P>4%2,'I&TP)Z4F)
M]0'92(G#2,'@'DC!ZP)("<-(B?")VTCWT$DAW4@AZ$P)Z$F)S4V-I`29>8):
M2(G(2<'E!4C!Z!M,">A)B<U$`>!)B?1(P>8>2<'L`DD)]$@#;"2X2(G.18GD
M2/?632'E2"'>2`-<),!,">Y)B<5(C:PUF7F"6DB)QDG!Y05(P>X;3`GN28G%
M`>Y(B<U(P>$>2,'M`D@)S4B)P8GM2/?13"'A22'M3`-D),A,">E)B?5(C9P+
MF7F"6DB)\4G!Y05(P>D;3`GI28GU`=E(B<-(P>`>2,'K`D@)PTB)\(G;2/?0
M22'=2"'H3`GH28G-38VD!)EY@EI(B<A)P>4%2,'H&TP)Z$F)S40!X$F)]$C!
MYAY)P>P"20GT2`-L)-!(B<Y%B>1(]]9-(>5((=Y(`UPDV$P)[DF)Q4B-K#69
M>8):2(G&2<'E!4C![AM,">Y)B<4![DB)S4C!X1Y(P>T"2`G-2(G!B>U(]]%,
M(>%)(>U,`V0DX$P)Z4F)]4B-G`N9>8):2(GQ2<'E!4C!Z1M,">E)B?4!V4B)
MPTC!X!Y(P>L"2`G#2(GPB=M(]]!)(=U((>A,">A)B<U-C:0$F7F"6DB)R$G!
MY05(P>@;3`GH28G-1`'@28GT2,'F'DG![`))"?1(`VPDZ$B)SD6)Y$CWUDTA
MY4@AWD@#7"3P3`GN28G%2(VL-9EY@EI(B<9)P>4%2,'N&TP)[DF)Q0'N2(G-
M2,'A'DC![0)("<U(B<&)[4CWT4PAX4DA[4P#9"3X3`GI28GU2(V<"YEY@EI(
MB?%)P>4%2,'I&TP)Z4F)]0'92(G#2,'@'DC!ZP)("<-(B?")VTCWT$DAW4@A
MZ$P)Z$F)S4V-I`29>8):2(G(2<'E!4C!Z!M,">A)B<U$`>!)B?1(P>8>2<'L
M`DD)]$@#+"1(B<Y%B>1(]]9-(>5((=Y(`UPD"$P)[DF)Q4B-K#69>8):2(G&
M2<'E!4C![AM,">Y)B<4![DB)S4C!X1Y(P>T"2`G-2(G!B>U(]]%,(>%)(>U,
M`V0D$$P)Z4F)]4B-G`N9>8):2(GQ2<'E!4C!Z1M,">E)B?4!V4B)PTC!X!Y(
MP>L"2`G#2(GPB=M(]]!)(=U((>A,">A)B<U-C:0$F7F"6DB)R$G!Y05(P>@;
M3`GH28GU2,'F'DG![0)$`>!)B<Q)"?5(`VPD&$B)SD6)[4CWUDTA[$@AWD@#
M7"0@3`GF28G$2(VL-9EY@EI(B<9)P>0%2,'N&TP)YDF)S$C!X1Y)P>P"`?5(
MB<9)"<Q(B<%%B>1(]]%,(>9,(>E,`VPD*$@)\4B)[DB-G`N9>8):2(GI2,'F
M!4C!Z1M("?$!RTB)P4C!X!Y(P>D"2`G!B<A(B<%,,>%,`V0D,$@QZ4F-M`VA
MZ]EN2(G928G=2<'E!4C!Z1M,">D!SDB)Z4C!Y1Y(P>D"28GU2`GIB<U(B>E(
M,<%)P>4%2#'938VD#*'KV6Y(B?%(P>D;3`GI1`'A28G<2,'C'DG![`))B<U)
M"=Q)P>4%1(GC28G$3`-D)#A(B=A(,>A(`VPD0$@Q\$V-I`2AZ]EN2(G(2,'H
M&TP)Z$0!X$F)]$C!YAY)P>P"28G%20GT2<'E!46)Y$R)YD@QWD@#7"1(2#'.
M2(VL-:'KV6Y(B<9(P>X;3`GN`>Y(B<U(P>$>2,'M`DF)]4@)S8GM2(GI3#'A
M2#'!2(V<"Z'KV6Y(B?%(P>D;2<'E!4P#9"103`GI`=E(B<-(P>`>2,'K`DF)
MS4@)PTG!Y06)VTB)V$@QZ$@#;"182#'P38VD!*'KV6Y(B<A(P>@;3`GH1`'@
M28GT2,'F'DG![`))B<5)"?1)P>4%18GD3(GF2#'>2`-<)&!(,<Y(C:PUH>O9
M;DB)QDC![AM,">X![DB)S4C!X1Y(P>T"28GU2`G-2<'E!8GM2(GI3#'A2#'!
M2(V<"Z'KV6Y(B?%(P>D;3`GI`=E(B<-(P>L"2,'@'DP#9"1H2`G#28G-B=M)
MP>4%2(G82#'H2`-L)'!(,?!-C:0$H>O9;DB)R$C!Z!M,">A$`>!)B?1(P>8>
M2<'L`DF)Q4D)]$G!Y05%B>1,B>9(,=Y(`UPD>$@QSDB-K#6AZ]EN2(G&2,'N
M&TP)[@'N2(G-2,'A'DC![0))B?5("<U)P>4%B>U(B>E,,>%(,<%(C9P+H>O9
M;DB)\4C!Z1M,">D!V4B)PTC!X!Y(P>L"28G-2`G#3`.D)(````!)P>4%B=M(
MB=A(,>A(`ZPDB````$@Q\$V-I`2AZ]EN2(G(2,'H&TP)Z$0!X$F)]$C!YAY)
MP>P"28G%20GT2<'E!46)Y$R)YD@QWD@#G"20````2#'.2(VL-:'KV6Y(B<9(
MP>X;3`GN`>Y(B<U(P>$>2,'M`DF)]4@)S4G!Y06)[4B)Z4PQX4P#I"28````
M2#'!2(V<"Z'KV6Y(B?%(P>D;3`GI`=E(B<-(P>`>2,'K`DF)S4@)PXG;2(G8
M2#'H2#'P38VD!*'KV6Y(B<A(P>@;2<'E!4@#K"2@````3`GH1`'@28GT2,'F
M'DG![`))B<5)"?1)P>4%18GD3(GF2#'>2`.<)*@```!(,<Y(C:PUH>O9;DB)
MQDC![AM,">X![DB)S4C!X1Y(P>T"28GU2`G-2<'E!8GM2(GI3#'A3`.D)+``
M``!(,<%(C9P+H>O9;DB)\4C!Z1M,">D!V4B)PTC!X!Y(P>L"28G-2`G#2<'E
M!8G;2(G82#'H2#'P38VD!*'KV6Y(B<A(P>@;3`GH1`'@28GT2,'F'DG![`))
MB<5)"?1)P>4%1(GF28GL3`.D)+@```!(B?5(,=U(`YPDP````$@QS4V-I"RA
MZ]EN2(G%2,'M&TP)[4F)S4C!X1Y)P>T"00'L20G-3(GE18GM2,'E!4R)Z4@Q
M\4@QP4B-G`NAZ]EN3(GA2,'I&T@)Z4B)Q4C!X!Y(P>T"`=E("<6XW+P;CTB)
MPT@#G"3(````B>U)B>Y-(>Y(`?-(B>Y,">Y,(>9,"?9)B<Y(`?-(B<Y)P>8%
M2,'N&TP)]@'S3(GF2<'D'DC![@),">9)B<1,`Z0DT````(GV28GV22'N30'E
M28GT20GL22',30GT28G>30'E28G<2<'F!4G![!M-"?1%`>Q)B<U(P>$>2<'M
M`DD)S42)Z4F)Q4P#K"38````28G.22'V3`'M28G-20GU22'=30GU38GF20'M
M3(GE2<'F!4C![1M,"?5$`>U)B=U(P>,>2<'M`DD)W42)ZTF)Q4P#K"3@````
M28G>22'.3`'N28G=20G-32'E30GU28GN20'U2(GN2<'F!4C![AM,"?9$`>Y-
MB>5)P>0>2<'M`DT)Y46)[$F)Q4P#K"3H````38GF22'>3`'I38GE20G=22'M
M30GU28GV20'-2(GQ2<'F!4C!Z1M,"?%$`>E)B>U(P>4>2<'M`DD)[42)[4F)
MQ4P#K"3P````28GN32'F3`'K28GM30GE22'U30GU28G.20'=2(G+2<'F!4C!
MZQM,"?-$`>M)B?5(P>8>2<'M`DD)]42)[DF)Q4P#K"3X````28GV22'N30'L
M28GU20GM22'-30GU28G>30'E28G<2<'F!4G![!M-"?1%`>Q)B<U(P>$>2<'M
M`DD)S42)Z4F)Q4P#K"0``0``28G.22'V3`'M28G-20GU22'=30GU38GF20'M
M3(GE2<'F!4C![1M,"?5$`>U)B=U(P>,>2<'M`DD)W42)ZTF)Q4P#K"0(`0``
M28G>22'.3`'N28G=20G-32'E30GU28GN20'U2(GN2<'F!4C![AM,"?9$`>Y-
MB>5)P>0>2<'M`DT)Y46)[$F)Q4P#K"00`0``38GF22'>3`'I38GE20G=22'M
M30GU28GV20'-2(GQ2<'F!4C!Z1M,"?%$`>E)B>U(P>4>2<'M`DD)[42)[4F)
MQ4P#K"08`0``28GN3`'K28GM32'F30GE22'U30GU28G.20'=2(G+2<'F!4C!
MZQM,"?-$`>M)B?5(P>8>2<'M`DD)]42)[DF)Q4P#K"0@`0``28GV22'N30'L
M28GU20GM22'-30GU28G>30'E28G<2<'F!4G![!M-"?1%`>Q)B<U(P>$>2<'M
M`DD)S42)Z4F)Q4P#K"0H`0``28G.22'V3`'M28G-20GU22'=30GU38GF20'M
M3(GE2<'F!4C![1M,"?5$`>U)B=U(P>,>2<'M`DD)W42)ZTF)Q4P#K"0P`0``
M28G>22'.3`'N28G=20G-32'E30GU28GN20'U2(GN2<'F!4C![AM,"?9$`>Y-
MB>5)P>0>2<'M`DT)Y46)[$F)Q4P#K"0X`0``38GF22'>3`'I38GE20G=22'M
M30GU28GV20'-2(GQ2<'F!4C!Z1M,"?%$`>E)B>U)P>T"2,'E'DD)[42)[4F)
MQ4P#K"1``0``28GN32'F3`'K28GM30GE22'U30GU28G.20'=2(G+2<'F!4C!
MZQM,"?-$`>M)B?5(P>8>2<'M`DD)]42)[DF)Q4P#K"1(`0``28GV22'N30'L
M28GU20GM22'-30GU28G>30'E28G<2<'F!4G![!M-"?1%`>Q)B<U(P>$>2<'M
M`DD)S42)Z4F)Q4P#K"10`0``28G.3`'M28G-20GU22'V22'=30GU38GF20'M
M3(GE2<'F!4C![1M,"?5$`>U)B=U(P>,>2<'M`DD)W42)ZTF)Q4P#K"18`0``
M28G>2`.$)&`!``!)(<Y,`>Y)B=U)"<U(`<%-(>5-"?5)B>Y)`?5(B>Y)P>8%
M2,'N&TP)]D0![DV)Y4G!Y!Y)P>T"30GE18GL3(G@38GE2`G822'=2"'H3`GH
M28GU2`'!2(GP2,'H&TG!Y05,">@!P4B)Z$C!Y1Y(P>@"28G.2`GH2<'F!8G%
MN-;!8LI)B<5,`ZPD:`$``$P!ZTF)[4TQY4DQ]4D!W4B)RTC!ZQM,"?-$`>M)
MB?5(P>8>2<'M`DF)WDD)]4B)QD@#M"1P`0``18GM2<'F!4D!]$R)[D@Q[D@Q
MSDD!]$B)WDC![AM,"?9$`>9)B<Q(P>$>2<'L`DF)]DD)S$B)P4@#C"1X`0``
M18GD2`'-3(GA3#'I2<'F!4@QV4@!S4B)\4C!Z1M,"?%)B=Y(P>,>2<'N`@'I
M2(G%20G>2`.L)(`!``!%B?9,B?-,,>-(,?-,`>U)B<U(`=U(B<M)P>4%2,'K
M&TP)ZP'K2(GU2,'F'DC![0))B=U("?5(B<9(`[0DB`$``(GM2<'E!4D!]$B)
M[DPQ]D@QSDD!]$B)WDC![AM,">Y)B<U(P>$>2<'M`D0!YDF)Q$D)S4P#I"20
M`0``18GM3(GI2#'I2#'930'T28GV20',2(GQ2<'F!4C!Z1M,"?%$`>%)B=Q(
MP>,>2<'L`DF)SDD)W$B)PT@#G"28`0``18GD2<'F!4@!W4R)XTPQZT@Q\T@!
MW4B)RTC!ZQM,"?-)B?9(P>8>2<'N`@'K2(G%20GV2`.L)*`!``!%B?9,B?9,
M,>9(,<Y,`>U)B=U(`?5(B=Y)P>4%2,'N&TP)[@'N2(G-2,'A'DC![0))B?5(
M"<U(B<%(`XPDJ`$``(GM2<'E!4D!S$B)Z4PQ\4@QV4D!S$B)\4C!Z1M,">E)
MB=U(P>,>2<'M`D0!X4F)Q$D)W4P#I"2P`0``18GM3(GK2#'K2#'S30'T28G.
M20'<2(G+2<'F!4C!ZQM,"?-$`>-)B?1(P>8>2<'L`DF)WDD)]$B)QD@#M"2X
M`0``18GD2`'U3(GF3#'N2#'.2`'U2(G>2,'N&TG!Y@5,"?9)B<Y(P>$>2<'N
M`@'N2(G%20G.2`.L),`!``!%B?9,B?%,,>%(,=E,`>U)B?5(`<U(B?%)P>4%
M2,'I&TP)Z0'I2(G=2,'C'DC![0))B<U("=U(B<-(`YPDR`$``(GM2<'E!4D!
MW$B)ZTPQ\T@Q\TD!W$B)RTC!ZQM,">M)B?5(P>8>1`'C2<'M`DF)Q$P#I"30
M`0``20GU18GM3(GN30'T2#'N28G>2#'.2<'F!4D!]$B)WDC![AM,"?9$`>9)
MB<Q(P>$>2<'L`DF)]DD)S$B)P4@#C"38`0``18GD2<'F!4@!S4R)X4PQZ4@Q
MV4@!S4B)\4C!Z1M,"?%)B=Y(P>,>2<'N`@'I2(G%20G>2`.L).`!``!%B?9,
MB?-,,>-(,?-,`>U)B<U(`=U(B<M)P>4%2,'K&TP)ZP'K2(GU2,'F'DC![0))
MB=U("?5(B<9(`[0DZ`$``(GM2<'E!4D!]$B)[DPQ]D@QSDD!]$B)WDC![AM,
M">Y)B<5,`ZPD\`$``$0!YDF)S$C!X1Y)P>P"20G,18GD30'U28GV3(GA2<'F
M!4@QZ4@QV4D!S4B)\4C!Z1M,"?%$`>E)B=U(P>,>2<'M`DF)SDD)W4G!Y@5$
MB>M)B<5,`ZPD^`$``$P![4F)W4TQY4DQ]4D![4B)S4C![1M,"?5)B<Y$`>U(
M`X0D``(``$F)]4G![0)(P>8>2<'F'DD)]4B)SDD!Z$6)[4C![@))`=M)`<1,
MB>A,"?9(,=A-`>I%B<!(,<A%B=)%B=M)C0P$2(GH28GL2<'D!4C!Z!M,">`!
MR$@!PD*-!`Z)TDB)%TR)1PA(B4<03(E7&$R)7R!(@<0(`@``6UU!7$%=05[#
M9BX/'X0``````$%7059!54F)_4%455-(@^P(2(7_=&A,BS73B"``387V=%P/
MM@=)B?<\/71DA,!T8$F)_$F#Q`%!#[8$)#P]=`2$P'7O12GL28L>2(7;="]-
M8^1,B?4/'P!,B>),B>Y(B=_HZN+__X7`=0="@#PC/70G2(/%"$B+70!(A=MU
MVDB#Q`@QP%M=05Q!74%>05_#D$4QY.NR#Q\`3"GU2HU$(P%(P?T#08DO2(/$
M"%M=05Q!74%>05_#9BX/'X0``````$B#[!@QP$B-="0,Z##___](@\08PV9F
M+@\?A```````4TB)^TB#[!`/'X0``````$B-="0,,<!(B=_H`?___TB%P'0N
M2&-4)`Q(BP7@AR``2(T$T$B+4`A(A=)(B1!TT$B#P`A(BU`(2(722(D0=?#K
MODB#Q!!;PP\?A```````55-(@^P(BSV4AR``Z#_D__^+/8F'(`!(BX!@`@``
M2(MH".@IY/__BSUSAR``#[:8Q`0``.@7Y/__2(M`"(/C?P^W0"#!X`<)V&:)
M10*+/4V'(`#H^./__XL]0H<@`$B+@&`"``!(BU@(Z.+C__\QTKZ+6T``2(G'
MZ,/C__^+/1V'(`!(B4,HZ,3C__^+/0Z'(`!(BX!@`@``2(M8".BNX___2(N`
M@`8``(L]\88@`$B)0S#HF./__XL]XH8@`$B+@&`"``!(BU@(Z(+C__\QTDB#
MN/@)````=!F+/<"&(`#H:^/__TB+@/@)``!(BY"H````BSVGAB``2(E3..A.
MX___2(N`8`(``(L]D88@`$B+0`A(QT!``````.@PX___2(N`8`(``(L]<X8@
M`$B+0`A(QT`@`````.@2X___BSU<AB``2(N`8`(``$B+6`CH_.+__TB+@'`"
M``!(B4-(2(/$"%M=PV8N#Q^$``````!(B6PDZ$B)7"3@2(G]3(ED)/!,B6PD
M^$B![+@```!(A?]T!8`_`'4H2(N<))@```!(BZPDH````$R+I"2H````3(NL
M)+````!(@<2X````P^B[X/__2(7`28G$=,M,B>?H.^/__TB%P$B)PP^$CP``
M`(![$RX/A)T```!(@\,32(GOZ-G@__](B=])B<7HSN#__T&-?`4"2&/_Z%'B
M__](B=E)B<5(B<=(B>J^K%E``#'`Z'GC__^_`0```$B)XDR)[N@YX/__@_C_
M3(GO=!"+1"08)0#P```]`$```'1AZ)S?__],B>_H=-___TR)Y^BLXO__2(7`
M2(G##X5Q____3(GGZ/C@__](B>_H0.#__^D3____#Q\`#[9#%(3`#X0Y____
M/"X/A4____^`>Q4`#X0G____Z4#___\/'T0``.B[_O__ZYUF#Q^$``````!!
M5S'`059!54%428G\55-(B?-(@^PH@#X]#Y3`2`'#2(G?Z.G?__](C70D'$F)
MQ4R)YS'`Z,?[__](A<!(B<4/A/L```!(B<?HP]___T2)ZD@YT`^#SP```(ML
M)!Q!#[8$)#P]#X2.`0``A,`/A(8!``!,B>+K#F8/'X0``````$"$]G0-2(/"
M`0^V,D"`_CUU[D0IXDB+!52$(`!"C7PJ`DB-+.CH]N#__TB%P$B)10`/A%0!
M``"+5"0<2(L%+H0@`$F-3"0!2(L$T$$/MA0DA-*($'4;ZQX/'X0```````^V
M$4B#P`%(@\$!A-*($'0%@/H]=>K&`#TQT@\?1```#[8,$XA,$`%(@\(!A,EU
M\#'`2(/$*%M=05Q!74%>05_##Q^```````^V`TB#PP&(10!(@\4!A,!U[NO4
M#Q]``$R+/:F#(`!)@S\`#X2N````3(GX,>UF+@\?A```````2(/`"(/%`4B#
M.`!U\XUU`DAC]DC!Y@.+!<.#(`"%P'0O3(G_Z)?@__](A<!)B<9(B05:@R``
M='-(8\U)QT3."`````");"0<Z;#^__\/'P!(B??'!8.#(``!````Z-[?__](
MA<!)B<9T04ACS4R)_DB)QTB-%,T`````2(E,)`CH6^#__TR)-02#(`!(BTPD
M".NH#Q]$```QTNF6_O__OA`````Q[>EL____N/_____I_?[__V9F+@\?A```
M````2(EL)/!,B60D^$B)_4B)7"3H2('L*!```$F)]+K_#P``2(GFO[)90`!D
M2(L$)2@```!(B80D"!```#'`Z`_=__^%P`^.?P```(U(_TACV8`\'`!T:TAC
MV$B)VKXO````2(GGZ'C>__](A<!T6XL]38(@`.CXWO__2(G92(GB2(GN2(G'
MZ/??__](BX0D"!```&1(,P0E*````'5'2(N<)!`0``!(BZPD&!```$R+I"0@
M$```2('$*!```,,/'T``A<EUE`\?0`"+/?*!(`#HG=[__TR)XDB)[DB)Q^A?
MW?__ZZ;H&-W__P\?A```````4TB)^XL]QH$@`.AQWO__2(V0F````$B)WK\!
M````Z)W?__^%P'0),<!;PP\?1```BSV:@2``Z$7>__^+@+`````E`/```#T`
M0```=!V+/7V!(`#H*-[__XN`L````"4`\```/0"@``!UO4B)W[X"````Z/G>
M__^%P`^4P`^VP%O#9F9F9F9F+@\?A```````2(/L"(L]-H$@`.CAW?__N<%9
M0`"Z8!Y``+[+64``2(G'2(/$".GVW?__9@\?1```2(/L"(L]!H$@`.BQW?__
M2(G'Z+G___^+/?.`(`#HGMW__T&XBUM``$4QR;I`5$``3(G!ON=90`!(B<=(
M@\0(Z?S=__]F9F8N#Q^$``````!54TB!["@@``!D2(L$)2@```!(B80D&"``
M`#'`Z$_;__^YO5E``(G"OOQ90``QP$B)Y^B)WO__A<!X;4B-M"00$```N@`0
M``!(B>?H`-O__TACZ(7M>%&-?0%(8__H'MW__TB%P$B)PW0^2(VT)!`0``!(
MB>I(B<?HD]S__\8$*P!(BY0D&"```&1(,Q0E*````$B)V'452('$*"```%M=
MPP\?@``````QV^O5Z$_;__]F9F9F9F8N#Q^$``````#I.____V9F+@\?A```
M````055!5$F)_+\*6D``55-(B?-(@>P8$```9$B+!"4H````2(F$)`@0```Q
MP.B@]___OB\```!,B>=(B<7H$-O__TB%P'0W3(GFOQ-:0``QP.B\^O__2(N4
M)`@0``!D2#,4)2@```!,B>`/A38!``!(@<08$```6UU!7$%=PTR)Y^B<VO__
M2(G?OB!:0`!!B<7H#-W__TB)PV8/'X0``````$B%VW2@@#L`N`A:0`!(#T38
M2(7M=!-(B=Y(B>_HC]O__X7`#X29````2(G?Z$_:__]!B<%(F(!\`_\O=1M(
MC4P#_V8/'T0``,8!`$B#Z0%!@^D!@#DO=/!#C40-`3W_#P``#X\]____38G@
MN2):0`!(B=J^05M``$B)YS'`Z,[<__^+/<A^(`#H<]O__TB-D)@```!(B>:_
M`0```.A_V?__A<!U'8L]I7X@`.A0V___BX"P````)0#P```]`(```'04OB!:
M0``Q_^@RW/__2(G#Z2K___^^`0```$B)Y^@-W/__A<!UVTB)YK\36D``Z'SY
M__](B>?H5-K__TF)Q.FP_O__Z(?9__\/'X``````#[8/A,ET'4B-5P%(B?AF
MD(#Y+P^V"D@/1,)(@\(!A,EU[O/#2(GXPP\?A```````2(7_4TB)^W0O@#\`
M="KH+=G__TB-5`/_2#G3<@SK/Y!(@^H!2#G:=`>`.B]T\NLE@#HO=6\/'P"_
M`@```.B.VO__2(7`=%EFQP`N`%O#9I"`.B]T"4B#Z@%(.=-R\D@YVG3-#Q]$
M``!(@^H!2#G3<P6`.B]T\D@IVDB-0@)(/0`0``!W&TB)WDB#P@&_(,1@`.C:
MU___N"#$8`!;PP\?`#'`6\-;OR):0`#I8=G__Y!(@^PXOR1:0`!D2(L$)2@`
M``!(B40D*#'`2(L%.!4``$B)!"1(BP4U%0``2(E$)`A(BP4Q%0``2(E$)!!(
MBP4M%0``2(E$)!@/MP4I%0``9HE$)"`QP.@%]?__,<"_+5I``.CY]/__,<"_
M-5I``.CM]/__,<"_/EI``.CA]/__,<"_15I``.C5]/__,<"_55I``.C)]/__
M,<"_"EI``.B]]/__,<"_85I``.BQ]/__,<"_:UI``.BE]/__,<"_=5I``.B9
M]/__,<"_$UI``.B-]/__,<"_?UI``.B!]/__,<"_B%I``.AU]/__,<"_DUI`
M`.A)]/__2(7`=`](B<:_:UI``#'`Z'7W__\QP+^D6D``Z"GT__](A<!T#TB)
MQK^V6D``,<#H5??__S'`O\%:0`#H"?3__TB%P'0\2(G&OPI:0``QP.@U]___
M,<"^[5I``+]%6D``Z"3W__](BT0D*&1(,P0E*````'5:2(/$.,,/'X``````
M,<"_T5I``.B\\___2(7`=!=(B<:_85I``#'`Z.CV___KL68/'T0``$B-="01
MO^):0`"Y"@```/.F=9A(C70D&[]A6D``,<#HO/;__^N%Z-76__\/'T0``(L%
MJA\@`(/X_W0%\\,/'P!(@^P(,<"_85I``.A0\___2(7`=",/MA`QP(32=`@Q
MP(#Z,`^5P(D%=!\@`$B#Q`C##Q^``````#'`Z^H/'T``2(/L".B'UO__B<?H
M,-;__TB%P'0+2(L`2(/$",,/'P`QP.OT9F9F+@\?A```````05=!5DF)_D%5
M0;WY6D``0515O>]:0`!32(/L2$C'!"3Y6D``2,=$)`CO6D``3(UD)!!(QT0D
M$/Q:0`!(QT0D&/):0`!(QT0D(/=:0`!(QT0D*`E;0`!(QT0D,`````#K)P\?
M@`````!(B<?HX-C__TB%P'1+2(7M=#=)BP0D28GM28/$"$B)Q3'`3(GOZ%[R
M__](A<!(B<-,B?9T!8`X`'7&3(GO,<#HA/7__TB%[77)2(/$2%M=05Q!74%>
M05_#3(GWZ'C5__](B=])B<?H;=7__TF-?`<"Z//6__])B=A)B<=(B<>Y(%I`
M`$R)\KY!6T``,<#H%MC__TR)_DR)[S'`Z"GU___KHP\?@`````!!5T%6055!
M5$F)_+\*6D``55-(@>R(@0``9$B+!"4H````2(F$)'B!```QP$C'1"0P(%M`
M`$C'1"0X"%I``$C'1"1``````$C'1"1PMEI``$C'1"1XKUI``$C'A"2`````
M)5M``$C'A"2(````S%I``$C'A"20````+5M``$C'A"28`````````$C'1"10
M%%M``$C'1"18,5M``$C'1"1@`````.@W\?__2(7`=`F`.``/A:D#```QP.@"
M_O__2(7`28G%#X2X`P``20^^70"$VW0EZ'C7__],B>H/'T0``$B+"/8$60AU
M`\8"7TB#P@%(#[X:A-MUZ$B-;"1XO[9:0`#K$0\?0`!(@\4(2(M]^$B%_W0S
M,<#HQ/#__TB%P$B)PW3D@#@`=-](B<?H__;__X7`=--(B=_HP]3__TB%P$B)
MPW5<#Q\`2(M<)#!(A=L/A!H!``"`.P"]`0```'4EZ0L!```/'P!(8\5(BUS$
M,$B%VP^$]P```(/%`8`[``^$ZP```$B)W^BC]O__A<!TUTB)W^AGU/__2(7`
M2(G#=,=(B=_HA]/__TR)[TB)Q>A\T___1(VT!00$``!-8_9,B??H^=3__TV)
MZ4B)QTB)Q4&X.EM``+DB6D``2(G:OC];0``QP.@6UO__OL`!``!(B>_HB=+_
M_X/X_P^$@````(L]^G<@`.BEU/__2(V0F````$B)[K\!````Z-'5__^%P`^$
MB0```$F+%"1(BST&>"``2(GIO@!<0``QP#';Z#W4__](BY0D>($``&1(,Q0E
M*````$B)V`^%.P@``$B!Q(B!``!;74%<05U!7D%?PY`QV^DJ____9@\?A```
M````Z+O1__]$BP!!@_@1#X1N____28L4)$B+/9MW(`!(B>F^P%M``#'`,=OH
MTM/__^N3BSU*=R``Z/73__^+@+`````E`/```#T`0```#X56____BSTI=R``
MZ-33__^+F+0```#H:=+__SG##X4X____BST+=R``Z+;3__^+@+`````E_P$`
M`#W``0``#X47____3(GWZ*C3__^_\EI``$B)PS'`Z+GN__](A<!(B<</A)X!
M``#HR-+__TF+/"1(B<;HS/;__TB%P$F)Q0^$@0$``$R)[^C8T?__@_@#?C-(
M8]"_2%M``+D%````28UT%?SSIG4=@_@$#X0G!@``@^@$2)A!@'P%_R\/A!8&
M```/'P`QP.C9^O__A<!U%C'V3(GOZ*O3__^%P(E$)"0/A2D!``"^[5I``+]A
M6D``,<#H7O'__^CIT/__0;F+6T``08G`N2):0`!(B>J^9EM``$B)WS'`13'D
MZ!;4___K/`\?0`#H2]#__X,X$75`08/$`>BMT/__2,<$)(M;0`!!B<!%B>&Y
M(EI``$B)ZKYT6T``2(G?,<#HV-/__[[``0``2(G?Z$O0__^#^/]TMDB)[^CN
MS___2(G>OPI:0``QP.C/\/__2(G?Z)?Z___IY?W__V:02(G'2(E$)!CH@_K_
M_TB+1"082(G'Z(;1__](B</IP?W__[\46T``NP$```#K$F:02&/#@\,!2(M\
MQ%!(A?]T)C'`Z#GM__](A<!TY(`X`'3?2(G'Z$?1__](A<!)B<5TS^D$_/__
M0;T96T``Z2?\__]-BRPDZ7;^__^Z`@```$C'QN[___^)Q^@ST___BWPD)$B-
MM"1P`0``N@8```#H+='__X"\)'`!````=0Z`O"1Q`0``0P^$!`4``(M\)"0Q
MTC'VZ/C2__^ZB:O-[[G^W+J8OO#ATL-(B90D^````$B-E"0H`0``2,>$)/``
M```!(T5G2(F,)``!``!(QX0D"`$``'94,A!(B;0D$`$``$C'A"08`0``````
M`$C'A"0@`0```````,>$)&@!````````2(E4)"AF#Q^$``````"+?"0D2(VT
M)'`!``"Z`(```.AZT/__A<!!B<0/CH0!``!(BXPD&`$``$ECQ(T4P4@YRDB)
ME"08`0``#Y+!2,'H'0^VR4@!C"0@`0``2`&$)"`!``!(8X0D:`$``(7`#X0T
M`0``ND````!(C;P$*`$``$B-M"1P`0``*<)!.=1!B=9%#T[T36/N3(GJZ"#0
M__^+A"1H`0``1`'P@_A`B80D:`$```^%5O___TB-A"1P`0``2(V\)/````!%
M*?1)`<7H&]7__P\?`$&#_#\/CJ4```!%B>9-B>\/'X0``````$F+#TB-O"3P
M````08/N0$B)C"0H`0``28M/"$B)C"0P`0``28M/$$B)C"0X`0``28M/&$B)
MC"1``0``28M/($B)C"1(`0``28M/*$B)C"10`0``28M/,$B)C"18`0``28M/
M.$F#QT!(B8PD8`$``.B,U/__08/^/W^&08/L0$2)XL'J!HG0P>(&2(/``4$I
MU$C!X`9)`<5(BWPD*$ECU$R)[N@IS___1(FD)&@!``#I;/[__P\?0`!,C:PD
M<`$``.DC____BWPD).ARSO__3(ND)!@!``!,BZPD(`$``$R)X$C!Z`.#X#^)
MPL:$!"@!``"`C4`!@_@X#X]?`@``N3<```!(F#'V*=%(C;P$*`$``$ACT>CW
MS?__3(GH2(V\)/````!$B*PD8P$``$C!Z!A$B*0D9P$``(B$)&`!``!,B>A(
MP>@0B(0D80$``$R)Z$R-K"2A````2,'H"(B$)&(!``!,B>!(P>@8B(0D9`$`
M`$R)X$C!Z!"(A"1E`0``3(G@3(VD),````!(P>@(B(0D9@$``$V)YNACT___
M2(N$)/````!)@\8H2(G!B(0DHP```$C!Z1@/MM&(C"2@````2(G!2,'I$(B,
M)*$```!(B<%(BX0D^````$C!Z0B(C"2B````2(G!B(0DIP```$C!Z1B(C"2D
M````2(G!2,'I$(B,)*4```!(B<%(BX0D``$``$C!Z0B(C"2F````2(G!B(0D
MJP```$C!Z1B(C"2H````2(G!2,'I$(B,)*D```!(B<%(BX0D"`$``$C!Z0B(
MC"2J````2(G!B(0DKP```$C!Z1B(C"2L````2(G!2,'I$(B,)*T```!(B<%(
MBX0D$`$``$C!Z0B(C"2N````2(G!B(0DLP```$C!Z1B(C"2P````2(G!2,'I
M$(B,)+$```!(B<%(P>D(B(PDL@```.D3````9BX/'X0``````$$/ME4`28/%
M`4R)YS'`OF%;0`!)@\0"Z)3.__]-.?1UWTR-A"3`````QH0DZ`````!!N8M;
M0`"Y(EI``$B)ZKY26T``2(G?,<#H8L[__^F7^O__38MD)`A-A>0/A-_Y__],
MB>?H=\O__TB#^`,/ALWY__])C70$_+]-6T``N04```#SIDT/1.SIL_G__TB8
MN3\````Q]BG12(V\!"@!``!(8]'HF,O__TB-O"3P````Z'O1__](C90D*`$`
M`+D'````,<!(B=?S2*OI>OW__X"\)'(!``!!#X7N^O__@+PD<P$``$,/A>#Z
M__^`O"1T`0``2`^%TOK__X"\)'4!``!%#X7$^O__BWPD)+H"````2,?&QO__
M_^BTS?__BWPD)$B-M"1P`0``NBD```#HKLO__T&YBUM``$R-A"1P`0``Z?+^
M__\/'P#HH\K__P\?`$%505154TB#[`B+/5!O(`#H^\O__[]%6D``QH#%!```
M`3'`Z!CG__](A<!T"8`X,0^$B@(``#'`Z,/Q__^+/1UO(`#HR,O__[D+````
MN@$```"^A5M``$B)Q^AQR___2(7`#X2Y````@SUY?R```4B+0!!,BV@H#XZD
M````O0@````QV^LW9BX/'X0``````$F+="002(L%1'\@`$B+/"CH&\O__X7`
M=6>#PP&+!39_(`!(@\4(C5,!.=!^68L]G6X@`.A(R___,<F)VDR)[DB)Q^@)
MS/__2(7`=#1,BR!!]D0D#01UJ8L]<VX@`.@>R___3(GFN0(````QTDB)Q^C\
MR?__2(G&ZXP/'X``````BP72?B``C5#_.=H/A#<!``"+/3EN(`#HY,K__[D$
M````N@$```"^BEM``$B)Q^B-RO__2(7`2(G#=#-(BT`0BST+;B``2(LHZ+/*
M__^ZC%M``$B)QTB)[NASR?__2(M#$$B+&/9##D`/A2(!``"+/=QM(`#HA\K_
M_[D$````N@$```"^D5I``$B)Q^@PRO__2(7`2(G#=#@QP+\36D``Z(SE__](
MA<!(B<4/A(`!``!(BT,0BSV6;2``3(L@Z#[*__](B>I(B<=,B>;H`,G__XL]
M>FT@`.@ERO__BSUO;2``QH#%!````.@3RO__OPI:0`!(QX!(!P```````#'`
MZ"SE__](A<!(B072?2``#X2T````OL`!``!(B<?HK\?__X/X$700A<!T#(/X
M_P\?``^%>@$``$B#Q`A;74%<05W##Q^``````(/X`0^.P/[__[L!````9BX/
M'X0``````(L]ZFP@`(/#`>B2R?__3(GN2(G'Z'?'__\Y'5E](`!_W^F+_O__
M9BX/'X0``````(L]NFP@`.AER?__2(G>2(G'Z+K)___IP_[__P\?1```@'@!
M``^$<_W__V8/'T0``.EA_?__#Q\`2(L]`7T@`.A\\O__2(7`2(D%`GT@``^$
MP@```$B+0Q!,BR7A?"``2(LH]D4-!'1D2(M]$$R)YN@<RO__B<5(BT,02(L8
M]D,-!'1N2(M3$$B+!;)\(`")Z;^`7$``2(LP,<#H\<C__Y!(BP69?"``BST3
M;"``3(L@2(M#$$B+*.BTR/__3(GF2(GOZ#GI___I=/[__XL][FL@`.B9R/__
MN0(```!(B<<QTDB)[NAWQ___2(G'Z7O___^+/<EK(`#H=,C__S'2N0(```!(
MB=Y(B<?H4L?__TB)PNEQ____OUA<0`#H<,C__XG!2(L%%WP@`$B+%2!\(`"_
MJ%Q``$B+,#'`Z%'(__^054B)_5-(@^P(Z&+M__\/M@B$R71,2(U0`4B)PP\?
M0`"`^2\/M@I(#T3:2(/"`83)=>XQP.BW[___A<!T'4B%[708@'T``'02OCI;
M0`!(B=_H:\G__T@YV'0,2(/$"%M=PTB)P^O,2(/$"$B)[UM=Z=SD__]F9F8N
M#Q^$``````!(@^P(BSWV:B``Z*''__^^_____TB)Q^C$QO__BSW>:B``Z(G'
M__\QTKX`/$``2(G'2(/$".GVR/__D)"0D)"02(T%P0X@`$B%P'0,2(L-M0X@
M`.F8QO__,<GK]Y"0D)#SPV9F9F9F+@\?A```````2(EL)-A,B60DX$B-+0<*
M(`!,C27X"2``3(EL).A,B70D\$R)?"3X2(E<)-!(@^PX3"GE08G]28GV2,']
M`TF)U^A3Q/__2(7M=!PQVP\?0`!,B?I,B?9$B>]!_Q3<2(/#`4@YZW+J2(M<
M)`A(BVPD$$R+9"083(ML)"!,BW0D*$R+?"0P2(/$.,.0D)!(@^P(2(/$",,`
M```!``(`)7,O)7,`+W!R;V,O<V5L9B]E>&4`<&5R;'AS:2YC`$1Y;F%,;V%D
M97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O
M8R\E:2\E<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`
M4$523$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]3
M4$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]!4D=#
M`%!!4E]!4D=67S``4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)
M4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.
M`%!!4E]#3$5!3CT`,0!,24)0051(`$193$1?3$E"4D%265]0051(`%-(3$E"
M7U!!5$@`55-%4@!365-414T`+W1M<`!414U01$E2`%1-4`!54T523D%-10!P
M87(M`"5S)7,E<R5S`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E,#)X`"5S
M)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;``M90`M
M+0``7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("```````````"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P
M97)A=&EO;BD*````````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O
M<GD``````````"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I;&5D("AE<G)N;STE
M:2D*```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````````````````````````
M`,!#`1L#._0````=````P,#__Q`!````Q?__F`4``"#(__\X`0``P-W__X`!
M``"`WO__X`$``*#>___X`0```-___Q@"``!PX/__2`(``,#A__]P`@``X./_
M_\`"``#0Y/__Z`(``&#E__\(`P``D.7__R`#``#@Y?__.`,``*#F__]H`P``
ML.;__X`#``!@Z/__P`,``)#H___8`P``0.G__P@$```0Z___*`0``&#K__](
M!```D.O__V@$``"@[/__N`0``$#W__\(!0``(/O__T@%``"@^___@`4``.#[
M___`!0```/S__]@%```0_/__\`4````````4``````````%Z4@`!>!`!&PP'
M")`!```D````'````*B___]`!`````X01@X82@\+=PB``#\:.RHS)"(`````
M1````$0```#@QO__EA4```!"#A".`D@.&(T#0@X@C`1!#BB&!4$.,(,&1PZX
M!`-X%0XP00XH00X@0@X80@X00@X(````````7````(P````XW/__M@````!"
M#A"/`D(.&(X#0@X@C01%#BB,!4$.,(8&00XX@P=$#D`"<0H..$,.,$$.*$(.
M($(.&$(.$$(."$(+6PXX00XP00XH0@X@0@X80@X00@X(%````.P```"8W/__
M%0````!$#B!0#@@`'`````0!``"@W/__6`````!!#A"#`D<.(`).#A!!#@@L
M````)`$``.#<__]F`0```$$.$(8"00X8@P-$#B`#70$.&$$.$$$."```````
M```D````5`$``"#>__]'`0```$J&!(,%5`[``8P#C0)Q"@X(00L`````3```
M`'P!``!(W___%0(```!"#A"/`D0.&(X#0@X@C01"#BB,!40.,(8&00XX@P='
M#F`#``$*#CA!#C!!#BA"#B!"#AA"#A!"#@A("P`````D````S`$``!CA___H
M`````$J&`XP"3PZP((,$`J(*#@A%"P``````'````/0!``#@X?__@0````!!
M#A"#`FD*#@A&"P)0#@@4````%`(``%#B__\J`````$0.$&$."``4````+`(`
M`&CB__]$`````$0.$'L."``L````1`(``*#B__^Q`````$$.$(8"00X8@P-'
M#L!``I4*#AA!#A!!#@A("P`````4````=`(``##C__\%```````````````\
M````C`(``"CC__^I`0```$(.$(T"0@X8C`-)#B"&!$$.*(,%2@[`(`)="@XH
M00X@00X80@X00@X(00L`````%````,P"``"8Y/__*```````````````+```
M`.0"``"PY/__KP````!$#A"#`@))"@X(0PL"3`H."$0+0PH."$$+00X(````
M'````!0#```PY?__RP$```!$#D`#;`$*#@A("P`````<````-`,``.#F__],
M`````%0.$&P*#@A("P```````!P```!4`P``$.?__R0`````1`X06`H."$0+
M````````3````'0#```@Y___"0$```!"#A"/`D(.&(X#10X@C01(#BB,!4$.
M,(8&1@XX@P=$#H`!`ID*#CA!#C!!#BA"#B!"#AA"#A!"#@A!"P````!,````
MQ`,``.#G__^="@```$(.$(\"0@X8C@-"#B"-!$(.*(P%20XPA@9!#CB#!T<.
MP(,"`TL""@XX00XP00XH0@X@0@X80@X00@X(0@L``#P````4!```,/+__]\#
M````0@X0C0)"#AB,`T$.((8$00XH@P5$#C`#0`(*#BA!#B!!#AA"#A!"#@A(
M"P`````T````5`0``-#U__]T`````$$.$(8"1`X8@P-$#B`"50H.&$$.$$$.
M"$$+20X81`X000X(`````!0```",!```&/;__SH`````1`X0<0X(`"0```"D
M!```8+___PX"````00X0@P)$#C`#CP$*#A!##@A!"P`````4````S`0``!CV
M__\<```````````````4````Y`0``"#V__\"```````````````D````_`0`
M`!CV__^)`````%&,!88&7PY`1H,'CP*.`XT$``````````````````#P)$``
M`````-`D0``````````````````!``````````$``````````0`````````%
M`@````````$`````````$`(````````!`````````!H"`````````0``````
M``!I`@````````$`````````I0,````````,`````````*@=0```````#0``
M``````"<64```````!D`````````(&-@```````;``````````@`````````
M&@`````````H8V```````!P`````````"``````````$`````````&`"0```
M````]?[_;P````"0!4````````4`````````<!!````````&`````````)@&
M0```````"@`````````;!0````````L`````````&``````````5````````
M`````````````P````````!P96````````(`````````2`8````````4````
M``````<`````````%P````````!@%T````````<`````````T!9````````(
M`````````)``````````"0`````````8`````````/[__V\`````8!9`````
M``#___]O``````(`````````\/__;P````",%4``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````.&-@````````````````````````````UAU```````#F'4```````/8=
M0```````!AY````````6'D```````"8>0```````-AY```````!&'D``````
M`%8>0```````9AY```````!V'D```````(8>0```````EAY```````"F'D``
M`````+8>0```````QAY```````#6'D```````.8>0```````]AY````````&
M'T```````!8?0```````)A]````````V'T```````$8?0```````5A]`````
M``!F'T```````'8?0```````AA]```````"6'T```````*8?0```````MA]`
M``````#&'T```````-8?0```````YA]```````#V'T````````8@0```````
M%B!````````F($```````#8@0```````1B!```````!6($```````&8@0```
M````=B!```````"&($```````)8@0```````IB!```````"V($```````,8@
M0```````UB!```````#F($```````/8@0```````!B%````````6(4``````
M`"8A0```````-B%```````!&(4```````%8A0```````9B%```````!V(4``
M`````(8A0```````EB%```````"F(4```````+8A0```````QB%```````#6
M(4```````.8A0```````]B%`````````````````````````````````````
M`````````````/____\`````````````````````````````````````(R$O
M=7-R+V)I;B]P97)L"F5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@
M)'LQ*R(D0")])PH@("`@:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE
M('-H96QL"@IP86-K86=E(%]?<&%R7W!L.PH*(R`M+2T@5&AI<R!S8W)I<'0@
M;75S="!N;W0@=7-E(&%N>2!M;V1U;&5S(&%T(&-O;7!I;&4@=&EM92`M+2T*
M(R!U<V4@<W1R:6-T.PH*(VQI;F4@,34X"@IM>2`H)'!A<E]T96UP+"`D<')O
M9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@
M>PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(&UY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PH@("`@
M;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PH@("`@
M1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@
M=6YL:6YK('TL("1P87)?=&5M<"D["B`@("!R;61I<B`D<&%R7W1E;7`["B`@
M("`C($1O;B=T(')E;6]V92!T;W!D:7(@8F5C875S92!T:&ES(&-A=7-E<R!A
M(')A8V4@=VET:"!O=&AE<B!A<'!S"B`@("`C('1H870@87)E('1R>6EN9R!T
M;R!S=&%R="X*"B`@("!I9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7
M:6XS,B<I('L*("`@("`@("`C(%-O;65T:&EN9R!W96YT('=R;VYG('5N;&EN
M:VEN9R!T:&4@=&5M<&]R87)Y(&1I<F5C=&]R>2X@(%1H:7,*("`@("`@("`C
M('1Y<&EC86QL>2!H87!P96YS(&]N('!L871F;W)M<R!T:&%T(&1I<V%L;&]W
M('5N;&EN:VEN9R!S:&%R960*("`@("`@("`C(&QI8G)A<FEE<R!A;F0@97AE
M8W5T86)L97,@=&AA="!A<F4@:6X@=7-E+B!5;FQI;FL@=VET:"!A(&)A8VMG
M<F]U;F0*("`@("`@("`C('-H96QL(&-O;6UA;F0@<V\@=&AE(&9I;&5S(&%R
M92!N;R!L;VYG97(@:6X@=7-E(&)Y('1H:7,@<')O8V5S<RX*("`@("`@("`C
M($1O;B=T(&1O(&%N>71H:6YG(&]N(%=I;F1O=W,@8F5C875S92!O=7(@<&%R
M96YT('!R;V-E<W,@=VEL;`H@("`@("`@(",@=&%K92!C87)E(&]F(&-L96%N
M:6YG('1H:6YG<R!U<"X*"B`@("`@("`@;7D@)'1M<"`](&YE=R!&:6QE.CI4
M96UP*`H@("`@("`@("`@("!414U03$%412`]/B`G=&UP6%A86%@G+`H@("`@
M("`@("`@("!$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I
M<BDL"B`@("`@("`@("`@(%-51D9)6"`]/B`G+F-M9"<L"B`@("`@("`@("`@
M(%5.3$E.2R`]/B`P+`H@("`@("`@("D["@H@("`@("`@('!R:6YT("1T;7`@
M(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PH@("!R
M;2`M<F8@)R1P87)?=&5M<"<*("`@:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=
M.R!T:&5N"B`@("`@("!B<F5A:PH@("!F:0H@("!S;&5E<"`Q"B`@('@]8&5X
M<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*
M(CL*("`@("`@("`@("`@8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*("`@
M("`@("!M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@
M,CXF,2`F)SL*("`@("`@("!C;&]S92`D=&UP.PH@("`@("`@('-Y<W1E;2@D
M8VUD*3L*("`@("`@("!O=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C
M97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0H@("`@("`@("`@("`@+B`D=&UP
M+3YF:6QE;F%M92D["B`@("!]"GT@?0H*0D5'24X@>PH@("`@26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*"B`@("!E=F%L('L*"E]P87)?:6YI=%]E;G8H*3L*"FEF("AE>&ES=',@
M)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*("`@
M($!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[
M4$%27T%21T-]("T@,2D["B`@("`D,"`]("1%3E9[4$%27T%21U9?,'T["GT*
M96QS92!["B`@("!F;W(@*&ME>7,@)45.5BD@>PH@("`@("`@(&1E;&5T92`D
M14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["B`@("!]"GT*"FUY("1Q=6EE="`]
M("$D14Y6>U!!4E]$14)51WT["@HC(&9I>"`D<')O9VYA;64@:68@:6YV;VME
M9"!F<F]M(%!!5$@*;7D@)4-O;F9I9R`]("@*("`@('!A=&A?<V5P("`@(#T^
M("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`H@("`@7V5X92`@("`@
M("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE
M)R`Z("<G*2P*("`@(%]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/
M4S(O(#\@)UQ<)R`Z("<O)RDL"BD["@I?<V5T7W!R;V=N86UE*"D["E]S971?
M<&%R7W1E;7`H*3L*"B,@36%G:6,@<W1R:6YG(&-H96-K:6YG(&%N9"!E>'1R
M86-T:6YG(&)U;F1L960@;6]D=6QE<R![>WL*;7D@*"1S=&%R=%]P;W,L("1D
M871A7W!O<RD["GL*("`@(&QO8V%L("1324=[7U]705).7U]](#T@<W5B('M]
M.PH*("`@(",@0VAE8VL@9FEL92!T>7!E+"!G970@<W1A<G0@;V8@9&%T82!S
M96-T:6]N('M[>PH@("`@;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA
M<W0["B`@("!B:6YM;V1E*%]&2"D["@H@("`@;7D@)&)U9CL*("`@('-E96L@
M7T9(+"`M."P@,CL*("`@(')E860@7T9(+"`D8G5F+"`X.PH@("`@;&%S="!U
M;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["@H@("`@<V5E:R!?1D@L("TQ
M,BP@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@<V5E:R!?1D@L("TQ
M,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PH@("`@<F5A9"!?1D@L("1B=68L
M(#0["@H@("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["B`@("`C('U]
M?0H*("`@(",@17AT<F%C=&EN9R!E86-H(&9I;&4@:6YT;R!M96UO<GD@>WM[
M"B`@("!M>2`E<F5Q=6ER95]L:7-T.PH@("`@=VAI;&4@*"1B=68@97$@(D9)
M3$4B*2!["B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!M>2`D
M9G5L;&YA;64@/2`D8G5F.PH@("`@("`@(&]U=',H<7$H56YP86-K:6YG(&9I
M;&4@(B1F=6QL;F%M92(N+BXI*3L*("`@("`@("!M>2`D8W)C(#T@*"`D9G5L
M;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PH@
M("`@("`@(&UY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0[
M"B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*
M("`@("`@("!I9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP
M;7QP;'QI>'QA;"DD+VDI('L*("`@("`@("`@("`@;7D@*"1O=70L("1F:6QE
M;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["B`@("`@("`@("`@(&EF
M("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@
M("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("`@("`@
M8VQO<V4@)&]U=#L*("`@("`@("`@("`@("`@(&-H;6]D(#`W-34L("1F:6QE
M;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B`@("`@("`@("`@
M("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M
M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>
M+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PH@("`@
M("`@("`@("`C('-H;W5L9"!B92!M;W9E9"!T;R!?=&5M<&9I;&4H*0H@("`@
M("`@("`@("!M>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N
M86UE)&5X="(["B`@("`@("`@("`@(&]U=',H(E-(3$E".B`D9FEL96YA;65<
M;B(I.PH@("`@("`@("`@("!O<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE
M(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@
M("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("!C;&]S92`D;W5T
M.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)')E<75I
M<F5?;&ES='LD9G5L;&YA;65](#T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ
M.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["B`@("`@("`@("`@("`@("!B
M=68@/3X@)&)U9BP*("`@("`@("`@("`@("`@(&-R8R`]/B`D8W)C+`H@("`@
M("`@("`@("`@("`@;F%M92`]/B`D9G5L;&YA;64L"B`@("`@("`@("`@('T[
M"B`@("`@("`@?0H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@?0H@
M("`@(R!]?7T*"B`@("!L;V-A;"!`24Y#(#T@*'-U8B!["B`@("`@("`@;7D@
M*"1S96QF+"`D;6]D=6QE*2`]($!?.PH*("`@("`@("!R971U<FX@:68@<F5F
M("1M;V1U;&4@;W(@(21M;V1U;&4["@H@("`@("`@(&UY("1F:6QE;F%M92`]
M(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*("`@("`@
M("`@("`@;7D@)&ME>3L*("`@("`@("`@("`@9F]R96%C:"`H:V5Y<R`E<F5Q
M=6ER95]L:7-T*2!["B`@("`@("`@("`@("`@("!N97AT('5N;&5S<R`O7%$D
M;6]D=6QE7$4D+SL*("`@("`@("`@("`@("`@("1K97D@/2`D7SL@;&%S=#L*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES
M='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PH@("`@("`@('T@;W(@<F5T=7)N
M.PH*("`@("`@("`D24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE
M+R1M;V1U;&4B.PH*("`@("`@("!I9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D
M969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PH@("`@("`@("`@("!M>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PH@("`@("`@("`@
M("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@('!R:6YT("1F:"`D9FEL96YA
M;64M/GMB=69].PH@("`@("`@("`@("!S965K*"1F:"P@,"P@,"D["B`@("`@
M("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@
M("`@("`@("`@("!M>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG
M+"`D9FEL96YA;64M/GMC<F-]*3L*("`@("`@("`@("`@:68@*"1O=70I('L*
M("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@
M("!P<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@("`@
M("!C;&]S92`D;W5T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&]P96X@
M;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN
M;6]D92@D9F@I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*
M"B`@("`@("`@9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I
M;F0@)&UO9'5L92%<;B(["B`@("!]+"!`24Y#*3L*"B`@("`C($YO=R!L;V%D
M(&%L;"!B=6YD;&5D(&9I;&5S('M[>PH*("`@(",@:6YI=&EA;&EZ92!S:&%R
M960@;V)J96-T('!R;V-E<W-I;F<*("`@(')E<75I<F4@6%-,;V%D97(["B`@
M("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E($-A<G`Z.DAE879Y
M.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H@("`@(R!N;W<@;&5T)W,@=')Y(&=E
M='1I;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W:71H:6X*("`@(')E<75I<F4@
M24\Z.D9I;&4["@H@("`@(R!L;V%D(')E<W0@;V8@=&AE(&=R;W5P(&EN"B`@
M("!W:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L
M:7-T*5LP72D@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?
M1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@=6YL97-S("@D
M24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["B`@
M("`@("`@("`@(",@<F5Q=6ER92!M;V1U;&5S+"!D;R!O=&AE<B!E>&5C=71A
M8FQE(&9I;&5S"B`@("`@("`@("`@(&EF("@D9FEL96YA;64@/7X@+UPN<&UC
M/R0O:2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER92`D9FEL96YA;64["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@
M("`C(%-K:7`@06-T:79E4W1A=&4G<R!S:71E8W5S=&]M:7IE+G!L(&9I;&4Z
M"B`@("`@("`@("`@("`@("!D;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M
M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*("`@("`@("`@("`@?0H@("`@
M("`@('T*("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65]
M.PH@("`@?0H*("`@(",@?7U]"@H@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B
M4$M<,#`S7#`P-"(["B`@("`D<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[
M"GT*(R!]?7T*"B,@07)G=6UE;G0@<')O8V5S<VEN9R![>WL*;7D@0'!A<E]A
M<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D[
M"@ID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*"B1Q=6EE="`](#`@=6YL
M97-S("1%3E9[4$%27T1%0E5'?3L*(R!$;VXG="!S=V%L;&]W(&%R9W5M96YT
M<R!F;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET:&]U="`M+7!A<BUO<'1I
M;VYS"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P
M=&EO;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I<W1?8VUD(#T@<7<H"B`@
M("`@("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@:2`@(&EN<W1A;&Q?<&%R
M"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@("`@("!S("`@<VEG;E]P
M87(*("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@*3L*"B`@("`C(&EF('1H
M92!A<'`@:7,@:6YV;VME9"!A<R`B87!P;F%M92`M+7!A<BUO<'1I;VYS("TM
M<F5U<V4@4%)/1U)!32!`4%)/1U]!4D=6(BP*("`@(",@=7-E('1H92!A<'`@
M=&\@<G5N('1H92!G:79E;B!P97)L(&-O9&4@:6YS=&5A9"!O9B!A;GET:&EN
M9R!F<F]M('1H90H@("`@(R!A<'`@:71S96QF("AB=70@<W1I;&P@<V5T('5P
M('1H92!N;W)M86P@87!P(&5N=FER;VYM96YT(&%N9"!`24Y#*0H@("`@:68@
M*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*("`@("`@("!S
M:&EF="!`05)'5CL*("`@("`@("`D14Y6>U!!4E]!4%!?4D554T5](#T@<VAI
M9G0@0$%21U8["B`@("!]"B`@("!E;'-E('L@(R!N;W)M86P@<&%R;"!B96AA
M=FEO=7(*"B`@("`@("`@;7D@0&%D9%]T;U]I;F,["B`@("`@("`@=VAI;&4@
M*$!!4D=6*2!["B`@("`@("`@("`@("1!4D=66S!=(#U^("]>+2A;04E-3T),
M8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["@H@("`@("`@("`@("!I9B`H)#$@
M97$@)TDG*2!["B`@("`@("`@("`@("`@("!P=7-H($!A9&1?=&]?:6YC+"`D
M,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)TTG
M*2!["B`@("`@("`@("`@("`@("!E=F%L(")U<V4@)#(B.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G02<I('L*("`@("`@("`@
M("`@("`@('5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!E;'-I9B`H)#$@97$@)T\G*2!["B`@("`@("`@("`@("`@
M("`D;W5T(#T@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@
M*"0Q(&5Q("=B)RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=S:71E
M)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T(G
M*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@)V%L;"<["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=Q)RD@>PH@("`@("`@
M("`@("`@("`@)'%U:65T(#T@,3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E;'-I9B`H)#$@97$@)TPG*2!["B`@("`@("`@("`@("`@("!O<&5N("1L
M;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@
M)"$B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G
M5"<I('L*("`@("`@("`@("`@("`@("1C86-H95]N86UE(#T@)#(["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@('-H:69T*$!!4D=6*3L*"B`@("`@("`@
M("`@(&EF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PH@("`@("`@("`@
M("`@("`@9&5L971E("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@("`@
M("!I;FET7VEN8R@I.PH@("`@("`@("`@("`@("`@<F5Q=6ER92!005(Z.D1I
M<W0["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N
M;&5S<R!`05)'5CL*("`@("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"1?*2!F;W(@0$%21U8["B`@("`@("`@("`@("`@("!E>&ET.PH@("`@
M("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!U;G-H:69T($!)3D,L($!A
M9&1?=&]?:6YC.PH@("`@?0I]"@HC(%A86"`M+2!A9&0@+2UP87(M9&5B=6<@
M<W5P<&]R="$*"B,@?7U]"@HC($]U='!U="!M;V1E("@M3RD@:&%N9&QI;F<@
M>WM["FEF("@D;W5T*2!["B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W
M9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@
M("!R97%U:7)E($E/.CI&:6QE.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ
M6FEP.PH@("`@?0H*("`@(&UY("1P87(@/2!S:&EF="A`05)'5BD["B`@("!M
M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E
M;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R
M)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("!B;&5S<R@D
M9F@L("=)3SHZ1FEL92<I.PH*("`@("`@("`D>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["B`@("`@("`@*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0H@("`@("`@("`@
M("!O<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["B`@("!]"@H*("`@
M(&UY("5E;G8@/2!D;R!["B`@("`@("`@:68@*"1Z:7`@86YD(&UY("1M971A
M(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*("`@("`@("`@("`@
M)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B`@("`@("`@("`@("1M971A(#U^
M(',O7EQ3+BHO+VUS.PH@("`@("`@("`@("`D;65T82`]?B`O7B`@*%M>.ETK
M*3H@*"XK*20O;6<["B`@("`@("`@?0H@("`@?3L*"B`@("`C($]P96X@:6YP
M=70@86YD(&]U='!U="!F:6QE<R![>WL*("`@(&QO8V%L("0O(#T@7#0["@H@
M("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@4$%2+"`G/"<L
M("1P87(@;W(@9&EE("(D(3H@)'!A<B(["B`@("`@("`@8FEN;6]D92A005(I
M.PH@("`@("`@(&1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S
M(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*("`@('T*"B`@("!#<F5A=&50871H
M*"1O=70I(#L*("`@(`H@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*("`@
M("`@("`D;W5T+`H@("`@("`@($E/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"B`@("`@
M("`@,#<W-RP*("`@("D@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH*
M("`@("0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U
M;F1E9CL*("`@('-E96L@7T9(+"`P+"`P.PH@("`@;7D@)&QO861E<B`]('-C
M86QA<B`\7T9(/CL*("`@(&EF("@A)$5.5GM005)?5D520D%424U](&%N9"`D
M;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PH@("`@("`@(')E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@("`@(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"B`@("!]"B`@("!F
M;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["B`@("`@("`@;7D@
M)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*("`@("`@("`D=F%L(#T@979A
M;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*("`@("`@("!M>2`D;6%G:6,@
M/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["B`@("`@("`@;7D@
M)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*("`@("`@("`D
M;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B`@("`@("`@("`@("1M86=I8R`N
M("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0H@
M("`@("`@('UE9SL*("`@('T*("`@("1F:"T^<')I;G0H)&QO861E<BD["B`@
M("`D+R`]('5N9&5F.PH@("`@(R!]?7T*"B`@("`C(%=R:71E(&)U;F1L960@
M;6]D=6QE<R![>WL*("`@(&EF("@D8G5N9&QE*2!["B`@("`@("`@<F5Q=6ER
M92!005(Z.DAE879Y.PH@("`@("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*("`@("`@("!I;FET7VEN8R@I.PH*("`@("`@("!R97%U:7)E
M7VUO9'5L97,H*3L*"B`@("`@("`@;7D@0&EN8R`]('-O<G0@>PH@("`@("`@
M("`@("!L96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I"B`@("`@("`@?2!G<F5P
M('L*("`@("`@("`@("`@(2]"4T1004XO"B`@("`@("`@?2!G<F5P('L*("`@
M("`@("`@("`@*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@H@("`@("`@("`@("`H
M)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`H@("`@("`@
M("`@("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*("`@
M("`@("!]($!)3D,["@H@("`@("`@(",@1FEL92!E>&ES=',@=&5S="!A9&1E
M9"!T;R!F:7@@4E0@(S0Q-SDP.@H@("`@("`@(",@1G5N;GDL(&YO;BUE>&ES
M=&EN9R!E;G1R>2!I;B!?/"XN+BYA=71O+T-O;7!R97-S+U)A=R]:;&EB+V%U
M=&]S<&QI="YI>"X*("`@("`@("`C(%1H:7,@:7,@82!B86YD+6%I9"!F:7@@
M=VET:"!N;R!D965P97(@9W)A<W`@;V8@=&AE(&ES<W5E+@H@("`@("`@(",@
M4V]M96)O9'D@<&QE87-E(&=O('1H<F]U9V@@=&AE('!A:6X@;V8@=6YD97)S
M=&%N9&EN9R!W:&%T)W,@:&%P<&5N:6YG+`H@("`@("`@(",@22!F86EL960N
M("TM(%-T969F96X*("`@("`@("!M>2`E9FEL97,["B`@("`@("`@+UY?/"@N
M*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH[
M"B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*"B`@("`@
M("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["B`@
M("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O<F5A8V@@*'-O<G0@:V5Y
M<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N86UE+"`D9FEL92D["@H@
M("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I;F,I('L*("`@("`@("`@
M("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]
M*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D7SL*("`@("`@("`@
M("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@
M("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PH@
M("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD[
M"B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>
M0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AM>2`D<F5F(#T@
M)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["B`@("`@
M("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M9B`B)&1I<B\D,2(I('L*
M("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H(B1D
M:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@("`@("`@
M("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1N86UE
M(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@("`@("`@("`@(&YE>'0@
M:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O
M.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@("`@("`@("`@("`@("`@
M<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F
M:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*("`@("`@("`@("`@*3L*
M"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@("`@("`@("!I9B`H<F5F
M*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D9FEL92T^
M>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@
M("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG
M="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@("`@("!B:6YM;V1E*$9)
M3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`\1DE,13X["B`@("`@
M("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@("`@("`@("`@(%!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"051)37T@
M86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@("`@("`@
M("`@("!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD
M8V]N=&5N="P@)&9I;&4L("1N86UE*3L*("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*("`@("`@("`@
M("`@)&9H+3YP<FEN="@B1DE,12(I.PH@("`@("`@("`@("`D9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PH@("`@("`@("`@("`D
M9F@M/G!R:6YT*'-P<FEN=&8H"B`@("`@("`@("`@("`@("`B)3`X>"\E<R(L
M($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64*
M("`@("`@("`@("`@*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G
M3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN
M="@D8V]N=&5N="D["B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*"B`@("`C
M($YO=R!W<FET92!O=70@=&AE(%!!4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*
M("`@("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@
M("`D8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@
M("!I9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T
M*2E;.5TI('L*("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("!\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-
M1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@(R!7;W)K87)O=6YD
M(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@
M(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)
M3TX@?2!\?"`P.PH@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G
M(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@)&-T
M>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("!]"B`@
M("`@("`@96QS92!["B`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY
M("1F:"P@(CPD;W5T(BDI('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H
M*3L*("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@
M("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@('T*("`@("`@("!]
M"@H@("`@("`@("1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S
M="`Z("1M=&EM93L*("`@('T*("`@("1C86-H95]N86UE("X](")<,"(@>"`H
M-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PH@("`@)&-A8VAE7VYA;64@+CT@
M(D-!0TA%(CL*("`@("1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H
M+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I
M*2D["B`@("`D9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L
M;W-E.PH@("`@8VAM;V0@,#<U-2P@)&]U=#L*("`@(",@?7U]"@H@("`@97AI
M=#L*?0HC('U]?0H*(R!0<F5P87)E("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE
M(&-A8VAE('M[>PI["B`@("!L87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P
M;W,["@H@("`@7V9I>%]P<F]G;F%M92@I.PH*("`@(",@3F]W(&QO860@=&AE
M(%!!4B!F:6QE(&%N9"!P=70@:70@:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@
M("`@<F5Q=6ER92!005(["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["@H*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@
M/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I
M<F4@1FEL93HZ1FEN9#L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*
M("`@('T*("`@(&UY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@(&UY
M("1F:"`]($E/.CI&:6QE+3YN97<["B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H
M7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B`@("`D>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#
M86-H92P@)'II<#L*("`@("1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D
M>FEP.PH*("`@("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["B`@("!O=71S
M*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*"B`@
M("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S
M970@870@=&AI<R!P;VEN="$*("`@("`@("!F;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PH@("`@("`@("`@("!N97AT(&EF("1M96UB
M97(M/FES1&ER96-T;W)Y.PH@("`@("`@("`@("!M>2`D;65M8F5R7VYA;64@
M/2`D;65M8F5R+3YF:6QE3F%M93L*("`@("`@("`@("`@;F5X="!U;FQE<W,@
M)&UE;6)E<E]N86UE(#U^(&U["B`@("`@("`@("`@("`@("!>"B`@("`@("`@
M("`@("`@("`O/W-H;&EB+PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ
M0V]N9FEG>W9E<G-I;VY]+RD_"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG
M.CI#;VYF:6=[87)C:&YA;65]+RD_"B`@("`@("`@("`@("`@("`H6UXO72LI
M"B`@("`@("`@("`@("`@("`D"B`@("`@("`@("`@('UX.PH@("`@("`@("`@
M("!M>2`D97AT<F%C=%]N86UE(#T@)#$["B`@("`@("`@("`@(&UY("1D97-T
M7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D
M97AT<F%C=%]N86UE*3L*("`@("`@("`@("`@:68@*"UF("1D97-T7VYA;64@
M)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*("`@
M("`@("`@("`@("`@(&]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@
M<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["B`@
M("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!O=71S*'%Q*$5X
M=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B`@
M("`@("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D["B`@("`@("`@("`@("`@("!C:&UO9"@P-34U+"`D9&5S=%]N
M86UE*2!I9B`D7D\@97$@(FAP=7@B.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@?0H@("`@(R!]?7T*?0HC('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA
M:6XN<&P@=&\@<G5N+"!S:&]W('5S86=E('M[>PIU;FQE<W,@*"1005(Z.DQI
M8D-A8VAE>R1P<F]G;F%M97TI('L*("`@(&1I92`\/"`B+B(@=6YL97-S($!!
M4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO
M9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B`@("`@("`D,"!;
M("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC
M('U]?0H*<W5B($-R96%T95!A=&@@>PH@("`@;7D@*"1N86UE*2`]($!?.PH@
M("`@"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.E!A
M=&@["B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S
M*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R
M97%U:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@
M7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI
M8CL*("`@(')E<75I<F4@1'EN84QO861E<CL*("`@(')E<75I<F4@:6YT96=E
M<CL*("`@(')E<75I<F4@<W1R:6-T.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*
M("`@(')E<75I<F4@=F%R<SL*("`@(')E<75I<F4@0V%R<#L*("`@(')E<75I
M<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5R<FYO.PH@("`@<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.PH@("`@
M<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E
M<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R
M97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z.DAA;F1L93L*("`@(')E
M<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O;7!R97-S.CI:;&EB.PH@
M("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R97%U:7)E(%!!4CL*("`@
M(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@4$%2.CI$:7-T.PH@
M("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("!R97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["B`@("!R97%U:7)E(&%T=')I
M8G5T97,["B`@("!E=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@>R!R
M97%U:7)E(%=I;C,R('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T
M:6P@?3L*("`@(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S
M="!].PH@("`@979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U
M<F4@?3L*("`@(&5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L
M24\Z.G-C86QA<B!].PI]"@HC(%1H92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E
M(&%P<&5A<G,@:6X@;7EL9'(O;6MT;7!D:7(N8PHC(%1H:7,@8V]D92!A;'-O
M(&QI=F5S(&EN(%!!4CHZ4V5T=7!496UP(&%S('-E=%]P87)?=&5M<%]E;G8A
M"G-U8B!?<V5T7W!A<E]T96UP('L*("`@(&EF("AD969I;F5D("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*("`@("`@
M("`D<&%R7W1E;7`@/2`D,3L*("`@("`@("!R971U<FX["B`@("!]"@H@("`@
M9F]R96%C:"!M>2`D<&%T:"`H"B`@("`@("`@*&UA<"`D14Y6>R1??2P@<7<H
M(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"B`@("`@
M("`@<7<H($,Z7%Q414U0("]T;7`@+B`I"B`@("`I('L*("`@("`@("!N97AT
M('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["B`@("`@("`@;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I9#L*
M("`@("`@("`C(&1O97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@("!E
M=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT[
M"@H@("`@("`@(&EF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2![
M"B`@("`@("`@("`@("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@
M("`@("`@('T*("`@("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*("`@
M("`@("`@("`@)'5S97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@("`@
M("!E;'-E('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-
M17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@("`@
M("`@)'5S97)N86UE(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M<&1I
M<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTD=7-E<FYA;64B.PH@("`@
M("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.5GM0
M05)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY
M72D@>PH@("`@("`@("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE
M*3L*("`@("`@("`@("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@("`@
M<WES<F5A9"`D9F@L(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF("@D8G5F
M(&5Q(")<,$-!0TA%(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L("TU
M."P@,CL*("`@("`@("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*
M("`@("`@("`@("`@("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@("`@
M("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U
M9CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@
M("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@
M1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE
M=R!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@("`@
M("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N
M9"`U+C,Y"B`@("`@("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L
M('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("`@("`@
M("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO
M;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F
M:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*
M("`@("`@("`@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@
M("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@
M("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T
M>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@8VQO<V4H)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@
M("`@("`@("`@("1%3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@("`@("1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@("!]
M"@H@("`@("`@("1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@("`@
M;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*"B`@
M("`D<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY
M("@D97AT+"`D8W)C*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*
M"B`@("`D9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@("!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE;F%M
M92!I9B`M92`D9FEL96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@)&9I
M;&5N86UE.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N("AU;F1E
M9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@("!O
M<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN;6]D
M92@D9F@I.PH@("`@<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*(R!S86UE
M(&-O9&4@;&EV97,@:6X@4$%2.CI3971U<%!R;V=N86UE.CIS971?<')O9VYA
M;64*<W5B(%]S971?<')O9VYA;64@>PH@("`@:68@*&1E9FEN960@)$5.5GM0
M05)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO
M*2!["B`@("`@("`@)'!R;V=N86UE(#T@)#$["B`@("!]"@H@("`@)'!R;V=N
M86UE('Q\/2`D,#L*"B`@("!I9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X
M*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*("`@("`@("`D
M<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE
M+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["B`@("!]"@H@("`@:68@*"$D14Y6
M>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI(#X](#`I('L*("`@("`@("!I9B`H;W!E;B!M>2`D9F@L("<\)RP@
M)'!R;V=N86UE*2!["B`@("`@("`@("`@(')E='5R;B!I9B`M<R`D9F@["B`@
M("`@("`@?0H@("`@("`@(&EF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE
M?2(I('L*("`@("`@("`@("`@)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T[
M"B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"B`@("!]"@H@("`@9F]R
M96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@
M)$5.5GM0051(?2D@>PH@("`@("`@(&YE>'0@:68@97AI<W1S("1%3E9[4$%2
M7U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PH@("`@("`@("1D
M:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PH@("`@("`@("@H)'!R
M;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG
M>U]E>&5](BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B`@("`@("`@*"@D
M<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L
M87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M92(["B`@("!]"GT*"G-U8B!?9FEX7W!R;V=N86UE('L*("`@("0P
M(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["B`@("!I9B`H
M:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PH@("`@
M("`@("1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*
M("`@('T*"B`@("`C(%A86"`M(&AA8VL@=&\@;6%K92!05T0@=V]R:PH@("`@
M;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W
M9"@I"B`@("`@("`@("`@("`@("`Z("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W
M9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["B`@("!C:&]M<"@D<'=D
M*3L*("`@("1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L
M:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PH*("`@("1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M93L*?0H*<W5B(%]P87)?:6YI=%]E;G8@>PH@
M("`@:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PH@("`@
M("`@(')E='5R;CL*("`@('T@96QS92!["B`@("`@("`@)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*("`@('T*"B`@("!F;W(@*'%W*"!34$%73D5$(%1%
M35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I
M('L*("`@("`@("!D96QE=&4@)$5.5GLG4$%27R<N)%]].PH@("`@?0H@("`@
M9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PH@("`@("`@
M("1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@
M97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["B`@("!]"@H@("`@;7D@
M)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M("(["@H@("`@:68@*"1%3E9[4$%27U1%35!]*2!["B`@("`@("`@9&5L971E
M("1%3E9[4$%27T-,14%.?3L*("`@('T*("`@(&5L<VEF("@A97AI<W1S("1%
M3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*("`@("`@("!M>2`D=F%L=64@/2!S
M=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PH@("`@
M("`@("1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#
M3$5!3CTH7%,K*2\["B`@("!]"GT*"G-U8B!O=71S('L*("`@(')E='5R;B!I
M9B`D<75I970["B`@("!I9B`H)&QO9V9H*2!["B`@("`@("`@<')I;G0@)&QO
M9V9H(")`7UQN(CL*("`@('T*("`@(&5L<V4@>PH@("`@("`@('!R:6YT(")`
M7UQN(CL*("`@('T*?0H*<W5B(&EN:71?:6YC('L*("`@(')E<75I<F4@0V]N
M9FEG.PH@("`@<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG
M.CI#;VYF:6=[)%]]+"!Q=R@*("`@("`@("!A<F-H;&EB97AP('!R:79L:6)E
M>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`H@("`@("`@('9E;F1O<F%R8VAE
M>'`@=F5N9&]R;&EB97AP"B`@("`I.PI]"@HC(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,*(R!4:&4@;6%I;B!P86-K86=E(&9O<B!S8W)I<'0@97AE8W5T
M:6]N"@IP86-K86=E(&UA:6X["@IR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#
M+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["@ID
M:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA
M;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"B`@("!U;FQE<W,@
M+64@)'!R;V=N86UE.PH*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I
M9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`[
M"@I].PH*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"@I#3U)%.CIE>&ET*"0Q
M*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I
M92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["@HQ.PH*(VQI;F4@,3`Q,0H*
M7U]%3D1?7PH`````1T-#.B`H1&5B:6%N(#0N-RXR+34N.2XR,#$T,#,Q,C$W
M,S$I(#0N-RXR`$=#0SH@*$1E8FEA;B`T+C0N-RTR+C@N,C`Q-#`S,3(Q-#0U
M*2`T+C0N-P``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T
M92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU
M+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N
M:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R
M86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`+F1Y;F%M:6,`+F=O
M=``N9V]T+G!L=``N9&%T80`N8G-S`"YC;VUM96YT````````````````````
M````````````````````````````````````````````````````````````
M```````````````+`````0````(```````````)``````````@```````!P`
M```````````````````!````````````````````$P````<````"````````
M`!P"0```````'`(````````@````````````````````!```````````````
M`````"$````'`````@`````````\`D```````#P"````````)```````````
M``````````0````````````````````X````!0````(`````````8`)`````
M``!@`@```````#`#````````!@`````````(``````````0`````````-```
M`/;__V\"`````````)`%0```````D`4````````$`0````````8`````````
M"````````````````````#X````+`````@````````"8!D```````)@&````
M````V`D````````'`````0````@`````````&`````````!&`````P````(`
M````````<!!```````!P$````````!L%```````````````````!````````
M````````````3@```/___V\"`````````(P50```````C!4```````#2````
M``````8``````````@`````````"`````````%L```#^__]O`@````````!@
M%D```````&`6````````<``````````'`````@````@`````````````````
M``!J````!`````(`````````T!9```````#0%@```````)``````````!@``
M```````(`````````!@`````````=`````0````"`````````&`70```````
M8!<```````!(!@````````8````-````"``````````8`````````'X````!
M````!@````````"H'4```````*@=````````#@````````````````````0`
M``````````````````!Y`````0````8`````````P!U```````#`'0``````
M`$`$```````````````````0`````````!``````````A`````$````&````
M```````B0````````"(```````"<-P``````````````````$```````````
M`````````(H````!````!@````````"<64```````)Q9````````"0``````
M``````````````0```````````````````"0`````0````(`````````J%E`
M``````"H60```````%@#```````````````````(````````````````````
MF`````$````"``````````!=0````````%T```````#T````````````````
M````!````````````````````*8````!`````@````````#X74```````/A=
M````````)`4```````````````````@```````````````````"P````#@``
M``,`````````(&-@```````@8P````````@````````````````````(````
M````````````````O`````\````#`````````"AC8```````*&,````````(
M````````````````````"````````````````````,@````!`````P``````
M```P8V```````#!C````````"`````````````````````@`````````````
M``````#-````!@````,`````````.&-@```````X8P```````#`"````````
M!P`````````(`````````!``````````U@````$````#`````````&AE8```
M````:&4````````(````````````````````"``````````(`````````-L`
M```!`````P````````!P96```````'!E````````,`(`````````````````
M``@`````````"`````````#D`````0````,`````````H&=@``````"@9P``
M`````.1;```````````````````@````````````````````Z@````@````#
M`````````*##8```````A,,```````"@$```````````````````(```````
M`````````````.\````!````,````````````````````(3#````````5@``
M``````````````````$``````````0`````````!`````P``````````````
M``````````#:PP```````/@````````````````````!````````````````
#````
